@@ -1,24 +1,24 @@
 man.evenn <-
 function()
 {
-  write("        ,.-.,                                                                                    ", file="")
-  write("      .`     `.                                                                                  ", file="")
-  write("     /.-., ,.-.`            *       *                                 ****      **       *****   ", file="")
-  write("   .`    .`.    `.     ***   *     *   ***    ****   ****    *     * *    *   *  *      *     *  ", file="")
-  write("  / `.  /   `.  / `  *     *  *   *  *     * *    * *    *    *   *      *       *           *   ", file="")
-  write(" |    ',_____,'    | ******   *   *  ******  *    * *    *     * *      *        *           *   ", file="")
-  write(" `.     `   /     /  *         * *   *       *    * *    *     * *    *          *      *     *  ", file="")
-  write("   ',    '_'    ,'    *****     *     *****  *    * *    *      *    ****** * ******* *  *****   ", file="")
-  write("     `'-'` `'-'`                                                                                 ", file="")
+  write("        ,.-.,                                                                                      ", file="")
+  write("      .`     `.                                                                                    ", file="")
+  write("     /.-., ,.-.`            *       *                                   ****      **           *   ", file="")
+  write("   .`    .`.    `.     ***   *     *   ***    ****   ****              *    *   *  *         * *   ", file="")
+  write("  / `.  /   `.  / `  *     *  *   *  *     * *    * *    *      *   *      *       *        *  *   ", file="")
+  write(" |    ',_____,'    | ******   *   *  ******  *    * *    *      *   *     *        *       *   *   ", file="")
+  write(" `.     `   /     /  *         * *   *       *    * *    *       * *    *          *      *******  ", file="")
+  write("   ',    '_'    ,'    *****     *     *****  *    * *    *        *    ****** * ******* *      *   ", file="")
+  write("     `'-'` `'-'`                                                                                   ", file="")
   write("\n#####################", file="")
   write("# eVenn Quick Start #", file="")
   write("#####################", file="")
-  write("- Prototype:\n\t(annot=FALSE, path_res=\"\", path_lists=\"\", res=\"\", ud=FALSE, prop=FALSE, noms=\"\", overlaps=FALSE, f=0, Tk=FALSE, aa=FALSE)", file="")
-  write("\n- Text tabulated files must be placed alone in a folder.\n", file="")
-  write("\n- Linux users must use the put the folder path in \"path_lists\".\n", file="")
-  write("\n- Default option produce a classical Venn diagram:\n\tevenn()\n", file="")
-  write("\n- Venn diagram with up/down details and annotations:\n\tevenn(annot=TRUE, ud=TRUE)", file="")
-  write("- Venn diagram with custom short names of lists:\n\tevenn(noms=c(\"A\", \"B\", \"C\", \"D\"))\n", file="")
+  write("- Prototype:\n\t(annot=FALSE, path_res=\"\", path_lists=\"\", res=\"\", ud=FALSE, prop=FALSE, noms=\"\", overlaps=FALSE, f=0, aa=FALSE)", file="")
+  write("- Text tabulated files must be placed alone in a folder.", file="")
+  write("- Linux users must use the put the folder path in \"path_lists\".", file="")
+  write("- Default option produce a classical Venn diagram:\n\tevenn()", file="")
+  write("- Venn diagram with up/down details and annotations:\n\tevenn(annot=TRUE, ud=TRUE)", file="")
+  write("- Venn diagram with custom short names of lists:\n\tevenn(noms=c(\"A\", \"B\", \"C\", \"D\"))", file="")
   write("- Just the overlaps table:\n\tevenn(overlaps=TRUE)\n", file="")
   write("####################", file="")
   write("# eVenn Quick Help #", file="")
